Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(707)

Unified Diff: cc/trees/thread_proxy.h

Issue 133263004: Unifies LayerTreeHost::SetNeedsUpdateLayers and SetNeedsAnimate -- V2 (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: fix mojo build Created 6 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « cc/trees/single_thread_proxy.cc ('k') | cc/trees/thread_proxy.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: cc/trees/thread_proxy.h
diff --git a/cc/trees/thread_proxy.h b/cc/trees/thread_proxy.h
index 7da65a1835106447827ef55f3b2c8d489b9ef1dd..420cbba15ae9302a3888b1ccf8e31e5d31374b3c 100644
--- a/cc/trees/thread_proxy.h
+++ b/cc/trees/thread_proxy.h
@@ -49,7 +49,6 @@ class ThreadProxy : public Proxy,
virtual void SetVisible(bool visible) OVERRIDE;
virtual void CreateAndInitializeOutputSurface() OVERRIDE;
virtual const RendererCapabilities& GetRendererCapabilities() const OVERRIDE;
- virtual void SetNeedsAnimate() OVERRIDE;
virtual void SetNeedsUpdateLayers() OVERRIDE;
virtual void SetNeedsCommit() OVERRIDE;
virtual void SetNeedsRedraw(const gfx::Rect& damage_rect) OVERRIDE;
@@ -204,11 +203,11 @@ class ThreadProxy : public Proxy,
// Accessed on main thread only.
- // Set only when SetNeedsAnimate is called.
- bool animate_requested_;
+ // Set only when SetNeedsUpdateLayers is called.
+ bool update_requested_;
// Set only when SetNeedsCommit is called.
bool commit_requested_;
- // Set by SetNeedsAnimate, SetNeedsUpdateLayers, and SetNeedsCommit.
+ // Set by both SetNeedsUpdateLayers and SetNeedsCommit.
bool commit_request_sent_to_impl_thread_;
// Set by BeginMainFrame
bool created_offscreen_context_provider_;
« no previous file with comments | « cc/trees/single_thread_proxy.cc ('k') | cc/trees/thread_proxy.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698